/**
 * @author Christian Brel <christian@the6thscreen.fr, ch.brel@gmail.com>
 */

/// <reference path="../utils/Logger.ts" />
/// <reference path="./SocketManager.ts" />

declare var $: any; // Use 'JQuery' lib

class ViewportManager {

    private _sm : SocketManager;

    /**
     * The Username.
     *
     * @property _username
     * @type string
     */
    private _username:string;

    private _borderSize : number;

    private _width : number;
    private _height : number;

    /**
     * Constructor.
     *
     * @constructor
     */
    constructor() {
        this._username = "Unknown";
        this._borderSize = 3;
        this._width = -1;
        this._height = -1;
    }

    /**
     * Set SocketManager.
     *
     * @method setSocketManager
     * @param {SocketManager} socketManager - The SocketManager.
     */
    setSocketManager(socketManager:SocketManager) {
        this._sm = socketManager;
    }

    /**
     * Show connection menu.
     *
     * @method showConnectionMenu
     */
    showConnectionMenu() {
        $('#painthtml5_server_form').show();
    }

    /**
     * Hide connection menu.
     *
     * @method hideConnectionMenu
     */
    hideConnectionMenu() {
        $('#painthtml5_server_form').hide();
    }

    /**
     * Show viewport.
     *
     * @method showViewport
     */
    showViewport() {
        if(this._width != -1 && this._height != -1) {
            $('#main_content').css("border", "red " + this._borderSize + "px solid");
            /*$('#main_content').width($(window).width()-2*this._borderSize);
             $('#main_content').height($(window).height()-2*this._borderSize);*/

            $('#main_content').width(this._width);
            $('#main_content').height(this._height);

            $('#main_content').show();

            /*$(window).resize(function() {
             self.setProfil(self._username, $(window).width()-2*self._borderSize, $(window).height()-2*self._borderSize);
             });*/
        }
    }

    /**
     * Set Username.
     *
     * @method setUsername
     * @param {string} username - The Username.
     */
    setUsername(username: string) {
        this._username = username;
        $('#user_profil').html(this._username);
    }

    /**
     * Set Width.
     *
     * @method setWidth
     * @param {number} width - The viewport width.
     */
    setWidth(width: number) {
        this._width = width;
    }

    /**
     * Set Height.
     *
     * @method setHeight
     * @param {number} height - The viewport height.
     */
    setHeight(height: number) {
        this._height = height;
    }
}